package com.ruoyi.project.business.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.project.business.domain.TcAccountHistory;

import java.util.List;

/**
 * 客户（组织）履历Mapper接口
 * 
 * @author ruoyi
 * @date 2024-04-23
 */
public interface TcAccountHistoryMapper extends BaseMapper<TcAccountHistory>
{
    /**
     * 查询客户（组织）履历
     * 
     * @param id 客户（组织）履历主键
     * @return 客户（组织）履历
     */
    public TcAccountHistory selectTcAccountHistoryById(Long id);

    /**
     * 查询客户（组织）履历列表
     * 
     * @param tcAccountHistory 客户（组织）履历
     * @return 客户（组织）履历集合
     */
    public List<TcAccountHistory> selectTcAccountHistoryList(TcAccountHistory tcAccountHistory);

    /**
     * 新增客户（组织）履历
     * 
     * @param tcAccountHistory 客户（组织）履历
     * @return 结果
     */
    public int insertTcAccountHistory(TcAccountHistory tcAccountHistory);

    /**
     * 修改客户（组织）履历
     * 
     * @param tcAccountHistory 客户（组织）履历
     * @return 结果
     */
    public int updateTcAccountHistory(TcAccountHistory tcAccountHistory);

    /**
     * 删除客户（组织）履历
     * 
     * @param id 客户（组织）履历主键
     * @return 结果
     */
    public int deleteTcAccountHistoryById(Long id);

    /**
     * 批量删除客户（组织）履历
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcAccountHistoryByIds(Long[] ids);

    Long selectMaxVersion(Long accountId);
}
